-- -- COPYRIGHT NOTICE -- --
-- This work is covered by the LGPL License. You are
-- able to modify, distribute and sublicense this
-- work as long as you include the original or show
-- clearly how to obtain it.

-- NOTES:
-- - Filename:   GuiCreator.lua
-- - Written By: Trilesch and Digpoe
-- - Purpose:    Creates the CombatStatus Gui when called

local Gui       = require("CombatStatus.CombatGui.Gui") -- Gui creation widget
local Translate = require("CombatStatus.TranslateWidget.Translator") -- Translation widget

local width = 150

-- Clears stats when called
local function ClearStats()
	dstats = {
		HTake = 0,
		HDone = 0,
		DTake = 0,
		DDone = 0
	}
	main.Stats.DamageDoneText.Text = Translate("Damage.Done") ..": 0"
	main.Stats.DamageTakeText.Text = Translate("Damage.Taken") ..": 0"
	main.Stats.HealDoneText.Text = Translate("Heal.Done") ..": 0"
	main.Stats.HealTakeText.Text = Translate("Heal.Taken") ..": 0"
end

-- Creates the configuration Gui when called
local function CreateConfig()
end

function GuiCreator()
	local temp
	
	local main = Gui.new("Window")
	main.Rect = {
		X      =  10,
		Y      =  30,
		Width  = width,
		Height = 200 
	}
	main.BackgroundTransparency = 0
	
	temp = Gui.new("Label")
	temp.Parent = main
	temp.Name = "TitleLabel"
	temp = nil
	
	main.TitleLabel.Rect = {
		X      =   0,
		Y      =   0,
		Width  = width,
		Height =  18
	}
	main.TitleLabel.BackgroundTransparency = 0.5
	main.TitleLabel.Text = "CombatStatus"
	main.TitleLabel.TextAlignment = Turbine.UI.ContentAlignment.MiddleCenter
	
	temp = Gui.new("Button")
	temp.Parent = main
	temp.Name = "ClearButton"
	temp = nil
	
	main.ClearButton.Rect = {
		X      =  0,
		Y      = 20,
		Width  = width/2-1,
		Height = 18
	}
	main.ClearButton.BackgroundTransparency = 0.5
	main.ClearButton.Text = Translate("Clear")
	main.ClearButton.TextAlignment = Turbine.UI.ContentAlignment.MiddleCenter
	main.ClearButton.OnClick = ClearStats
	
	
	temp = Gui.new("Button")
	temp.Parent = main
	temp.Name = "ConfButton"
	temp = nil
	
	main.ConfButton.Rect = {
		X      = width/2+1,
		Y      = 20,
		Width  = width/2-1,
		Height = 18
	}
	main.ConfButton.BackgroundTransparency = 0.5
	main.ConfButton.Text = Translate("Config")
	main.ConfButton.TextAlignment = Turbine.UI.ContentAlignment.MiddleCenter
	main.ConfButton.OnClick = CreateConfig
	
	
	temp = Gui.new("Control")
	temp.Parent = main
	temp.Name = "Stats"
	temp = nil
	
	main.Stats.Rect = {
		X      = 0,
		Y      = 40,
		Width  = width,
		Height = 58
	}
	main.Stats.BackgroundTransparency = 0.5
	
	do
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "DamageDoneBar"
		temp = nil
		
		main.Stats.DamageDoneBar.Rect = {
			X      = 2,
			Y      = 2,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageDoneBar.BackgroundImage = "CombatStatus/Resources/BarShader.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "DamageDoneText"
		temp = nil
		
		main.Stats.DamageDoneText.Rect = {
			X      = 2,
			Y      = 2,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageDoneText.Text = Translate("Damage.Done") ..": 0"
		main.Stats.DamageDoneText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
		
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "DamageTakeBar"
		temp = nil
		
		main.Stats.DamageTakeBar.Rect = {
			X      = 2,
			Y      = 16,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageTakeBar.BackgroundImage = "CombatStatus/Resources/BarShader2.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "DamageTakeText"
		temp = nil
		
		main.Stats.DamageTakeText.Rect = {
			X      = 2,
			Y      = 16,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageTakeText.Text = Translate("Damage.Taken") ..": 0"
		main.Stats.DamageTakeText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
	end
	do
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "DamageDoneBar"
		temp = nil
		
		main.Stats.DamageDoneBar.Rect = {
			X      = 2,
			Y      = 2,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageDoneBar.BackgroundImage = "CombatStatus/Resources/BarShader.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "DamageDoneText"
		temp = nil
		
		main.Stats.DamageDoneText.Rect = {
			X      = 2,
			Y      = 2,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageDoneText.Text = Translate("Damage.Done") ..": 0"
		main.Stats.DamageDoneText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
		
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "DamageTakeBar"
		temp = nil
		
		main.Stats.DamageTakeBar.Rect = {
			X      = 2,
			Y      = 16,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageTakeBar.BackgroundImage = "CombatStatus/Resources/BarShader2.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "DamageTakeText"
		temp = nil
		
		main.Stats.DamageTakeText.Rect = {
			X      = 2,
			Y      = 16,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.DamageTakeText.Text = Translate("Damage.Taken") ..": 0"
		main.Stats.DamageTakeText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
	end
	
	do
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "HealDoneBar"
		temp = nil
		
		main.Stats.HealDoneBar.Rect = {
			X      = 2,
			Y      = 30,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.HealDoneBar.BackgroundImage = "CombatStatus/Resources/BarShader3.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "HealDoneText"
		temp = nil
		
		main.Stats.HealDoneText.Rect = {
			X      = 2,
			Y      = 30,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.HealDoneText.Text = Translate("Heal.Done") ..": 0"
		main.Stats.HealDoneText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
		
		temp = Gui.new("Control")
		temp.Parent = main.Stats
		temp.Name = "HealTakeBar"
		temp = nil
		
		main.Stats.HealTakeBar.Rect = {
			X      = 2,
			Y      = 44,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.HealTakeBar.BackgroundImage = "CombatStatus/Resources/BarShader4.tga"
		
		temp = Gui.new("Label")
		temp.Parent = main.Stats
		temp.Name = "HealTakeText"
		temp = nil
		
		main.Stats.HealTakeText.Rect = {
			X      = 2,
			Y      = 44,
			Width  = width - 4,
			Height = 12
		}
		main.Stats.HealTakeText.Text = Translate("Heal.Taken") ..": 0"
		main.Stats.HealTakeText.TextAlignment = Turbine.UI.ContentAlignment.MiddleLeft
	end
	
	
	main.Visible = true
	return main
end